@@ -19,7 +19,7 @@
 #
 
 # Soundcloud.com API client module for gPodder
-# Thomas Perl <thpinfo.com>; 2009-11-03
+# Thomas Perl <thp@gpodder.org>; 2009-11-03
 
 import gpodder
 
@@ -141,7 +141,9 @@ class SoundcloudUser(object):
 
             for track in tracks:
                 # Prefer stream URL (MP3), fallback to download URL
-                url = track.get('stream_url', track['download_url'])
+                url = track.get('stream_url', track['download_url']) + \
+                    '?consumer_key=%(consumer_key)s' \
+                    % { 'consumer_key': CONSUMER_KEY }
                 if url not in self.cache:
                     try:
                         self.cache[url] = get_metadata(url)
